@@ -13,7 +13,7 @@ class Tensor:
         if not isinstance(data, xp.ndarray):
             self.data = xp.array(data, dtype=dtype)
         elif dtype is not None:
-            self.data = data.astype(dtype)
+            self.data = data.astype(dtype, copy=False)
         else:
             self.data = data
         self.requires_grad = requires_grad # whether to compute gradients for this tensor
@@ -309,7 +309,12 @@ class Tensor:
         """Standard deviation of tensor elements over given axis."""
         from .functions.reductions import Std
         return Std(axis=axis, keepdims=keepdims, ddof=ddof)(self)
-    
+
+    def argmin(self, axis=None) -> 'Tensor':
+        """Indices of minimum values along an axis."""
+        result = xp.argmin(self.data, axis=axis)
+        return Tensor(result, requires_grad=False, name=self.name + "_argmin")
+
     def argmax(self, axis=None) -> 'Tensor':
         """Indices of maximum values along an axis."""
         result = xp.argmax(self.data, axis=axis)
@@ -440,6 +445,29 @@ class Tensor:
             new_tensor.grad = self.grad.copy()
         return new_tensor
 
+    def detach(self) -> 'Tensor':
+        """
+        Return a new tensor detached from the graph.
+        Shares the same underlying storage (no data copy) but does not
+        require gradients and has no grad_fn.
+        """
+        return Tensor(
+            data=self.data,  # share storage, no copy
+            requires_grad=False,
+            grad_fn=None,
+            name=self.name + "_detached",
+            dtype=self.data.dtype,
+        )
+
+    def clone(self) -> 'Tensor':
+        """
+        Return a copy of the tensor that participates in autograd.
+        If this tensor requires gradients, the clone will too, and
+        gradients will flow back to this tensor through the clone op.
+        """
+        from .functions.tensor_ops import Clone
+        return Clone()(self)
+
     def __getitem__(self, key):
         """Support slicing/indexing like a NumPy array while preserving metadata."""
         sliced_data = self.data[key]
@@ -518,27 +546,36 @@ class Tensor:
         return f"Tensor({self.data})"
 
 
-def zeros(shape: Union[int, List[int]], dtype: Optional[str] = None) -> Tensor:
-    return Tensor(xp.zeros(shape, dtype=dtype), requires_grad=False)
+def zeros(shape: Union[int, List[int]], dtype: Optional[str] = None,
+          requires_grad: bool = False) -> Tensor:
+    return Tensor(xp.zeros(shape, dtype=dtype), requires_grad=requires_grad)
 
-def ones(shape: Union[int, List[int]], dtype: Optional[str] = None) -> Tensor:
-    return Tensor(xp.ones(shape, dtype=dtype), requires_grad=False)
+def ones(shape: Union[int, List[int]], dtype: Optional[str] = None,
+         requires_grad: bool = False) -> Tensor:
+    return Tensor(xp.ones(shape, dtype=dtype), requires_grad=requires_grad)
 
-def zeros_like(tensor: Tensor) -> Tensor:
-    return Tensor(xp.zeros_like(tensor.data, dtype=tensor.data.dtype), requires_grad=False, name=tensor.name + "_zeros_like")
+def zeros_like(tensor: Tensor, requires_grad: bool = False) -> Tensor:
+    return Tensor(xp.zeros_like(tensor.data, dtype=tensor.data.dtype), requires_grad=requires_grad, name=tensor.name + "_zeros_like")
 
-def ones_like(tensor: Tensor) -> Tensor:
-    return Tensor(xp.ones_like(tensor.data, dtype=tensor.data.dtype), requires_grad=False, name=tensor.name + "_ones_like")
+def ones_like(tensor: Tensor, requires_grad: bool = False) -> Tensor:
+    return Tensor(xp.ones_like(tensor.data, dtype=tensor.data.dtype), requires_grad=requires_grad, name=tensor.name + "_ones_like")
 
-def empty(shape: Union[int, List[int]], dtype: Optional[str] = None) -> Tensor:
-    return Tensor(xp.empty(shape, dtype=dtype), requires_grad=False)
+def empty(shape: Union[int, List[int]], dtype: Optional[str] = None,
+          requires_grad: bool = False) -> Tensor:
+    return Tensor(xp.empty(shape, dtype=dtype), requires_grad=requires_grad)
 
-def arange(start: int, stop: int, step: int = 1, dtype: Optional[str] = None) -> Tensor:
-    return Tensor(xp.arange(start, stop, step, dtype=dtype), requires_grad=False)
+def arange(start: int, stop: int, step: int = 1, dtype: Optional[str] = None,
+           requires_grad: bool = False) -> Tensor:
+    return Tensor(xp.arange(start, stop, step, dtype=dtype), requires_grad=requires_grad)
 
-def eye(n: int, dtype: Optional[str] = None) -> Tensor:
-    return Tensor(xp.eye(n, dtype=dtype), requires_grad=False)
+def eye(n: int, dtype: Optional[str] = None,
+        requires_grad: bool = False) -> Tensor:
+    return Tensor(xp.eye(n, dtype=dtype), requires_grad=requires_grad)
+
+def argmin(tensor: Tensor, axis: Optional[int] = None) -> Tensor:
+    """Return indices of minimum values along an axis."""
+    return tensor.argmin(axis=axis)
 
 def argmax(tensor: Tensor, axis: Optional[int] = None) -> Tensor:
     """Return indices of maximum values along an axis."""
-    return tensor.argmax(axis=axis)
\ No newline at end of file
+    return tensor.argmax(axis=axis)
